@@ -1,28 +1,28 @@
 ;;; planner-bbdb.el --- BBDB integration for the Emacs Planner
 
-;; Copyright (C) 2001 John Wiegley
-;; Copyright (C) 2003 Sandra Jean Chua
+;; Copyright (C) 2001, 2003, 2004, 2005 Free Software Foundation, Inc.
+;; Parts copyright (C) 2004 Andrew J. Korty
 
 ;; Author: John Wiegley <johnw@gnu.org>
-;; Maintainer: Sacha Chua <sacha@free.net.ph>
-;; Version: 3.30
 ;; Keywords: planner, gnus
-;; URL: http://sacha.free.net.ph/notebook/wiki/PlannerMode.php#bbdb
+;; URL: http://www.plannerlove.com/
 
-;; This file is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
 ;; the Free Software Foundation; either version 2, or (at your option)
 ;; any later version.
 
-;; This file is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;;_ + Commentary:
 
@@ -37,6 +37,8 @@
 
 ;; Andrew J. Korty (ajk AT iu DOT edu) had the idea to add the mailto:
 ;; URI and provided the initial patch for it.
+;;
+;; Yann Hodique helped to port this to Muse.
 
 ;;; Code:
 
@@ -62,13 +64,14 @@ Suitable for use in `planner-annotation-functions'."
       (or (bbdb-record-getprop
            (bbdb-current-record) 'plan)
           ;; From a BBDB entry with a plan page; use that. Yay!
-          (concat "[[bbdb://"
-                  (emacs-wiki-replace-regexp-in-string
-                   " " "."
-                   (bbdb-record-name (bbdb-current-record)))
-                  "][" (bbdb-record-name (bbdb-current-record))
-                  "]]"))))
+          (planner-make-link
+           (concat "bbdb://"
+                   (planner-replace-regexp-in-string
+                    " " "." (bbdb-record-name (bbdb-current-record))))
+           (bbdb-record-name (bbdb-current-record))))))
 
+
+;;;###autoload
 (defun planner-bbdb-browse-url (url)
   "If this is a BBDB URL, jump to it."
   (when (string-match "^bbdb:/?/?\\(.+\\)" url)
@@ -79,7 +82,7 @@ Suitable for use in `planner-annotation-functions'."
 (defun planner-bbdb-resolve-url (id)
   "Replace ID with the blog, web or e-mail address of the BBDB record."
   (save-match-data
-    (when (string-match "^bbdb:/+" id)
+    (when (string-match "\\`bbdb:/+" id)
       (setq id (replace-match "" t t id)))
     (let ((record (car (bbdb-search (bbdb-records) id id id))))
       (or (and record
@@ -89,10 +92,10 @@ Suitable for use in `planner-annotation-functions'."
                      (concat "mailto:" (car (bbdb-record-net record))))))
           nil))))
 
-(planner-add-protocol "bbdb" 'planner-bbdb-browse-url 'planner-bbdb-resolve-url)
+(planner-add-protocol "bbdb:/+" 'planner-bbdb-browse-url 'planner-bbdb-resolve-url)
 (add-hook 'planner-annotation-functions 'planner-bbdb-annotation-from-bbdb)
-(custom-add-option 'planner-annotation-functions
-                   'planner-bbdb-annotation-from-bbdb)
+(custom-add-option 'planner-annotation-functions 'planner-bbdb-annotation-from-bbdb)
+
 (defalias 'planner-get-name-from-address 'planner-bbdb-get-name-from-address)
 
 (provide 'planner-bbdb)
