@@ -1,31 +1,30 @@
 ;;; planner-cyclic.el --- Cyclic task support for the Emacs Planner
 
-;; Copyright (C) 2004 Sandra Jean Chua <sacha@Free.net.ph>
+;; Copyright (C) 2004, 2005 Free Software Foundation, Inc.
+;; Parts copyright (C) 2005 Sergey Vlasov (vsu AT altlinux.ru)
 
 ;; Filename: planner-cyclic.el
-;; Version: 3.30
 ;; Author: Sacha Chua <sacha@free.net.ph>
 ;; Description: Provide cyclic task support
-;; URL: http://sacha.free.net.ph/notebook/emacs/emacs-wiki/planner-cyclic.el
-;; ChangeLog: http://sacha.free.net.ph/notebook/emacs/emacs-wiki/ChangeLog
-;; Compatibility: Emacs21
+;; URL: http://www.plannerlove.com/
+;; Compatibility: Emacs21, XEmacs21
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 ;;
@@ -62,31 +61,41 @@
   :type 'boolean
   :group 'planner)
 
+(defcustom planner-cyclic-task-description-format "%s from %s"
+  "Format used by `planner-cyclic-generate-task' when creating a task.
+This string must be a valid control string for `format'.  First format
+argument is the task description read from `planner-cyclic-diary-file',
+second argument is the date string.
+ 
+If this format is changed when you already have some cyclic tasks
+created with the old format, `planner-cyclic-create-tasks-maybe' will
+add the same tasks with the new format, unless you convert existing
+tasks to the new format manually."
+  :type 'string
+  :group 'planner)
+
 ;;; functions
+
 (defun planner-cyclic-get-cyclic-tasks (date &optional no-of-days)
   "For DATE, get the cyclic tasks."
-  (save-window-excursion
-    (save-excursion
-      (unwind-protect
-          (delq nil
-                (let* ((diary-display-hook nil)
-                       (diary-file planner-cyclic-diary-file)
-                       (list-diary-entries-hook '(include-other-diary-files))
-                       (entries (list-diary-entries
-                                 (if (stringp date)
-                                     (planner-filename-to-calendar-date date)
-                                   date) 1)))
-                  (mapcar (lambda (item)
-                            (when (string-match "#[A-C].+" (elt item 1))
-                              (match-string 0 (elt item 1))))
-                          entries)))))))
+  (let ((date (if (stringp date)
+		  (planner-filename-to-calendar-date date)
+		date)))
+    (delq nil
+	  (mapcar (lambda (item)
+		    (when (string-match "#[A-C].+" (elt item 1))
+		      (match-string 0 (elt item 1))))
+		  (planner-list-diary-entries planner-cyclic-diary-file
+                                              date 1)))))
 
 (defun planner-cyclic-generate-task (date task-string)
   "For DATE, generate a cyclic task based on TASK-STRING."
   (let ((info (planner-task-info-from-string date task-string)))
     (if info
         (setcar (nthcdr 4 info)
-                (concat (planner-task-description info) " from " date))
+		(format planner-cyclic-task-description-format
+			(planner-task-description info)
+                        date))
       (message "Cannot parse task %s" task-string))
     info))
 
@@ -97,14 +106,16 @@
           (new-task (planner-cyclic-generate-task date task-string)))
       (unless (planner-find-task new-task)
         (when (or planner-cyclic-diary-nag (not (planner-find-task orig-task)))
-          (planner-create-task-from-info new-task))))))
+          (planner-create-task-from-info new-task nil nil nil nil nil date))))))
 
+;;;###autoload
 (defun planner-cyclic-create-tasks-maybe ()
   "Maybe create cyclic tasks.
 This will only create tasks for future dates or today."
   (interactive)
   (when (and (planner-derived-mode-p 'planner-mode)
              (planner-page-name)
+             (not muse-publishing-p)
              (string-match planner-date-regexp (planner-page-name))
              (or (string< (planner-today) (planner-page-name))
                  (string= (planner-today) (planner-page-name))))
