@@ -1,7 +1,8 @@
 ;;; planner-diary.el --- Diary integration for the Emacs Planner (planner.el)
 
 ;; Copyright (C) 2003, 2004 Thomas Gehrlein <Thomas.Gehrlein AT t-online.de>
-;; Parts copyright (C) 2004 Travis B. Hartwell <nafai AT travishartwell.net>
+;; Parts copyright (C) 2004, 2005 Free Software Foundation, Inc.
+;; Parts copyright (C) 2005 Jody Klymak
 
 ;; Emacs Lisp Archive Entry
 ;; Filename: planner-diary.el
@@ -11,42 +12,42 @@
 ;; Author: Thomas Gehrlein <Thomas.Gehrlein@t-online.de>
 ;; Maintainer: Thomas Gehrlein <Thomas.Gehrlein@t-online.de>
 ;; Description: Integrate the Emacs Planner with Calendar and Diary
-;; URL: http://sacha.free.net.ph/notebook/emacs/dev/planner/planner-diary.el
-;; ChangeLog: Can be requested from the maintainer
-;; Compatibility: Emacs20, Emacs21
+;; URL: http://www.plannerlove.com/
+;; Compatibility: Emacs20, Emacs21, XEmacs21
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; PLANNER-DIARY
 
-;; (The following documentation describes the stable version of planner-diary
-;; (v1.0).  If planner-diary doesn't do what I claim here, then it's a bug and you
-;; will fix it.  This file contains additional code that is part of the
-;; development version of planner.  This code may or may not work.  Use it at your
-;; own risk.)
+;; The following documentation describes the stable version of
+;; planner-diary (v1.0).  If planner-diary doesn't do what I claim
+;; here, then it's a bug and you will fix it.  This file contains
+;; additional code that is part of the development version of planner.
+;; This code may or may not work.  Use it at your own risk.
 ;;
 ;;; Commentary:
-;; 
-;; If you use Emacs' diary feature, planner-diary could be helpful for you.  It
-;; puts all diary entries for the current day in the "* Diary" section of your day
-;; plan page.  This section is updated every time you display the file in Emacs.
-;; By default the diary section of past pages is not updated (it's pretty unlikely
-;; that you want to add new diary entries for the past).
+;;
+;; If you use Emacs' diary feature, planner-diary could be helpful for
+;; you.  It puts all diary entries for the current day in the "*
+;; Diary" section of your day plan page.  This section is updated
+;; every time you display the file in Emacs.  By default the diary
+;; section of past pages is not updated (it's pretty unlikely that you
+;; want to add new diary entries for the past).
 ;;
 ;; If you want to use planner-diary.el, put the file in your load path and add
 ;; this to your .emacs:
@@ -63,20 +64,7 @@
 ;;
 ;; You can use planner diary in two different ways:
 ;;
-;; 1) You can put the following line of lisp code in your day plan pages to
-;;    display your diary entries:
-;;
-;;    <lisp>(planner-diary-entries-here)</lisp>
-;;
-;;    You can do this automatically for all day plan pages:
-;;
-;;    (setq planner-day-page-template
-;;          "* Tasks\n\n\n* Diary\n\n<lisp>(planner-diary-entries-here)</lisp>\n\n* Notes")
-;;
-;;    When you open a day plan page outside emacs, you will see the line of lisp
-;;    code and not your diary entries.
-;;
-;; 2) If you want the saved files to contain your entries and not just a line
+;; 1) If you want the saved files to contain your entries and not just a line
 ;;    of lisp, add the following lines to your .emacs:
 ;;
 ;;    (setq planner-diary-use-diary t)
@@ -92,16 +80,30 @@
 ;;    inserts the diary section for the day, even if the day is in the past or
 ;;    if there is no Diary section in the buffer.
 ;;
+;; 2) (GNU EMACS ONLY) You can put the following line of lisp code in
+;;    your day plan pages to display your diary entries:
+;;
+;;    <lisp>(planner-diary-entries-here)</lisp>
+;;
+;;    You can do this automatically for all day plan pages:
+;;
+;;    (setq planner-day-page-template
+;;          "* Tasks\n\n\n* Diary\n\n<lisp>(planner-diary-entries-here)</lisp>\n\n* Notes")
+;;
+;;    When you open a day plan page outside emacs, you will see the
+;;    line of lisp code and not your diary entries.
+;;
 ;; If you want to see your diary entries for more than just 1 day, set
 ;; `planner-diary-number-of-diary-entries' accordingly.  This works for
 ;; either of the 2 approaches.
 ;;
-;; If you want to use the cal-desk package, simply follow the instructions in
-;; cal-desk.el.  If you get the cal-desk layout from the Calendar buffer, you get
-;; it in the day plan buffer, too.
+;; If you want to use the cal-desk package, simply follow the
+;; instructions in cal-desk.el.  If you get the cal-desk layout from
+;; the Calendar buffer, you get it in the day plan buffer, too.
 ;;
-;; If you use planner-diary, you might consider using the Calendar support of planner.
-;; To get Calendar integration add this to your .emacs:
+;; If you use planner-diary, you might consider using the Calendar
+;; support of planner.  To get Calendar integration add this to your
+;; .emacs:
 ;;
 ;;    (planner-insinuate-calendar)
 ;;
@@ -110,18 +112,6 @@
 ;; If you have questions about planner-diary, feature requests, bug reports or
 ;; anything else you want to tell me: thomas.gehrlein@t-online.de.
 
-;;; THANKS TO:
-
-;; - Jody Klymak (jklymak AT coas DOT oregonstate DOT edu)
-;;   Added some documentation
-;;
-;; - Sacha Chua (sacha AT free DOT net DOT ph)
-;;   Thoughts and ideas
-;;
-;; - Bastien Guerry
-;;   Bug report and appointment integration
-
-
 ;;; HISTORY:
 
 ;; version 1.0 First stable version.  Expected to work as documented.  Same
@@ -157,7 +147,7 @@
 
 ;; 1) Put the following line of lisp code in you day plan pages to display your
 ;;    diary entries:
-;; 
+;;
 ;;    <lisp>(planner-diary-entries-here)</lisp>
 ;;
 ;;    The function `planner-diary-entries-here' takes two optional args:  The
@@ -191,6 +181,14 @@
 
 ;;;_ + Contributors
 
+;; Jody Klymak (jklymak AT coas DOT oregonstate DOT edu) added some
+;; documentation.
+
+;; Sacha Chua (sacha AT free DOT net DOT ph) provided thoughts and
+;; ideas.
+
+;; Bastien Guerry provided a bug report and appointment integration.
+
 ;; Travis B. Hartwell (nafai AT travishartwell DOT net) helped fix
 ;; calendar desk entries and fixed a typo or two.
 
@@ -217,7 +215,7 @@
   "Non-nil means create diary section in future or present day pages."
   :type 'boolean
   :group 'planner-diary)
-  
+
 (defcustom planner-diary-file diary-file
   ;; FIXME: Test if this works as buffer-local var
   "*The diary file you want to use with planner-diary."
@@ -413,7 +411,9 @@ display using a fancy desk calendar."
               '(sort-diary-entries fancy-diary-display)))
            (no-of-days (or no-of-days planner-diary-number-of-days))
            (diary-file (or file planner-diary-file)))
-      (list-diary-entries date no-of-days)
+      (if (fboundp 'diary-list-entries)
+          (diary-list-entries date no-of-days)
+        (list-diary-entries date no-of-days))
       (switch-to-buffer fancy-diary-buffer)
       (let ((inhibit-read-only t))
         ;; return "No entries" if buffer is empty
@@ -467,39 +467,44 @@ Arguments NO-OF-DAYS and FILE are ignored."
 DATE is a list (month day year).  Optional arg TYPE ..." ; FIXME: doc for type
   (save-window-excursion
     (let* ((regexp planner-diary-exclude-regexp)
-	   (no-of-days planner-diary-number-of-days)
-	   (init-entries (flet ((message (&rest args) (ignore args)))
-			   (list-diary-entries date (if type 1 no-of-days))))
-	   (end-entries
-	    (mapcar
-	     '(lambda (seq)
-		(let ((seq2 (if (and (eq type 'appt)
-				     (string-match planner-diary-time-regexp (cadr seq)))
-				(planner-diary-appt-to-planner (cadr seq))
-			      (cadr seq))))
-		  (unless ; first check no excluded regexp
-		      (or (and (not (equal regexp ""))
-			       (string-match regexp seq2))
-					; then check appt not already there
-			  (string-match (substring seq2 0 (1- (length seq2)))
-					; bug in planner.el ? a space is added
-					; from diary entries to .diary.planner
-					(buffer-string))
-			  (if (eq type 'appt)
-			      (not (string-match planner-diary-time-regexp seq2))
-			    (and (eq type nil)
-				 planner-diary-exclude-appts-from-diary
-				 (string-match planner-diary-time-regexp
-					       (cadr seq)))))
-		    seq2))) init-entries)))
+           (no-of-days planner-diary-number-of-days)
+           (init-entries (flet ((message (&rest args) (ignore args)))
+                           (if (fboundp 'diary-list-entries)
+                               (diary-list-entries date (if type 1 no-of-days))
+                             (list-diary-entries date
+                                                 (if type 1 no-of-days)))))
+           (end-entries
+            (mapcar
+             '(lambda (seq)
+                (let ((seq2 (if (and (eq type 'appt)
+                                     (string-match planner-diary-time-regexp
+                                                   (cadr seq)))
+                                (planner-diary-appt-to-planner (cadr seq))
+                              (cadr seq))))
+                  (unless ; first check no excluded regexp
+                      (or (and (not (equal regexp ""))
+                               (string-match regexp seq2))
+                          ; then check appt not already there
+                          (string-match (substring seq2 0 (1- (length seq2)))
+                                        ; bug in planner.el ? a space is added
+                                        ; from diary entries to .diary.planner
+                                        (buffer-string))
+                          (if (eq type 'appt)
+                              (not (string-match planner-diary-time-regexp
+                                                 seq2))
+                            (and (eq type nil)
+                                 planner-diary-exclude-appts-from-diary
+                                 (string-match planner-diary-time-regexp
+                                               (cadr seq)))))
+                    seq2))) init-entries)))
       (mapconcat 'eval (delete-duplicates (remove nil end-entries)
-					  :test 'equal) "\n"))))
+                                          :test 'equal) "\n"))))
 
 (defun planner-diary-appt-to-planner (appt)
   "Convert APPT from diary format to planner format."
   (string-match "\\([0-9]+:[0-9]+[ap]?m?\\)[ ]+\\(.*\\)" appt)
   (let ((time (match-string 1 appt))
-	(task (match-string 2 appt)))
+        (task (match-string 2 appt)))
     (concat time " | " task)))
 
 
@@ -527,7 +532,7 @@ DATE is a list (month day year). NO-OF-DAYS defaults to
 
 (defun planner-diary-get-name ()
   "Return current filename."
-  (file-name-nondirectory (or (buffer-file-name) (buffer-name))))
+  (planner-page-name))
 
 ;;; LISP FUNCTIONS FOR USE IN PLANNER DAY PAGES
 ;;; arg FILE to specify a diary-file (suggested by David O'Toole)
@@ -619,6 +624,7 @@ You might want to use `planner-day-page-template' to do so."
 
 ;;; CODE FOR DEALING WITH SECTIONS
 ;; There's a lot of code duplication in the following 3 functions.
+;;;###autoload
 (defun planner-diary-update-section (file title text &optional force)
   ;;FIXME: Find a good place to insert a new section
   "Update FILE's existing section TITLE by replacing existing text with TEXT.
@@ -651,53 +657,6 @@ i.e. insert TITLE followed by TEXT at the top of the buffer."
       (unless (string= text "")
           (insert text "\n")))))
 
-
-(defun planner-diary-delete-section-text (file title)
-  "In FILE, delete the text of section TITLE."
-  ;; search for something like "^* Diary$", delete buffer content to the next
-  ;; "^* "
-  ;; sanity checks
-  (unless (equal major-mode 'planner-mode)
-    (error "This is not a planner buffer"))
-  (save-excursion
-    (goto-char (point-min))
-    (unless (re-search-forward (concat "^" title "$") (point-max) t)
-      (error "No \"%s\" section in this buffer" title))
-    ;; point is at the end of something like "* Diary"
-    ;; delete the old text
-    (let ((beg (point))
-          (end (if (re-search-forward "^* " (point-max) t)
-                   (progn (beginning-of-line)
-                          (backward-char 1)
-                          (point))
-                 (point-max))))
-      (delete-region beg end)
-      ;; point is at the end of "* Diary"
-      (insert "\n\n"))))
-
-
-(defun planner-diary-delete-section (file title)
-  "In FILE, delete the whole section TITLE, text plus title."
-  ;; search for something like "^* Diary$", delete buffer content to the next
-  ;; "^* "
-  ;; sanity checks
-  (unless (equal major-mode 'planner-mode)
-    (error "This is not a planner buffer"))
-  (save-excursion
-    (goto-char (point-min))
-    (unless (re-search-forward (concat "^" title "$") (point-max) t)
-      (error "No \"%s\" section in this buffer" title))
-    ;; point is at the end of something like "* Diary"
-    ;; delete the old text from the beginning of the line
-    (let ((beg (line-beginning-position))
-          (end (if (re-search-forward "^* " (point-max) t)
-                   (line-beginning-position)
-                   ;;                    (progn (beginning-of-line)
-                   ;;                           (backward-char 1)
-                   ;;                           (point))
-                  (point-max))))
-      (delete-region beg end))))
-
 (defun planner-diary-insert-diary (&optional force)
   "Insert the fancy diary for the day into the day plan file.
 If FORCE is non-nil, insert a diary section even if there is no
@@ -733,7 +692,7 @@ FORCE is non-nil, insert a diary section even if there is no
       ;; we are in the past -> do nothing, message when interactive
       (when (interactive-p)
         (message "No day plan buffer or date is in the past.  No diary entries inserted.")))))
-  
+
 (defun planner-diary-insert-appts (&optional force)
   "Insert the diary appointments for the day into the day plan file.
 If FORCE is non-nil, insert a diary appointments section even if there is no
@@ -880,6 +839,7 @@ FORCE is non-nil, insert a private appointments section even if there is no
         (message "No day plan buffer or date is in the past.  No diary entries inserted.")))))
 
 ;; UPDATE ALL DIARIES
+;;;###autoload
 (defun planner-diary-insert-all-diaries (&optional force)
   "Update all diary sections in a day plan file.
 If FORCE is non-nil, insert a diary section even if there is no section header.
@@ -896,6 +856,7 @@ Inserts only diaries if the corresponding `planner-diary-use-*' variable is t."
   (when planner-diary-use-public-diary
     (planner-diary-insert-public force)))
 
+;;;###autoload
 (defun planner-diary-insert-all-diaries-maybe (&optional force)
   "Update all diary sections in a day plan file.
 If the current day is in the past and FORCE is nil, don't do anything.
@@ -916,33 +877,38 @@ Inserts only diaries if the corresponding `planner-diary-use-*' variable is t."
   (when planner-diary-use-public-diary
     (planner-diary-insert-public-maybe force)))
 
-
+;;;###autoload
 (defun planner-diary-show-day-plan-or-diary ()
   "Show the day plan or diary entries for the date under point in calendar.
 Add this to `calendar-move-hook' if you want to use it.  In that case you
 should also `remove-hook' `planner-calendar-show' from `calendar-move-hook'."
   (interactive)
   (or (planner-calendar-show)
+      (and (fboundp 'diary-view-entries)
+           (diary-view-entries 1))
       (view-diary-entries 1)))
 
-
+;;;###autoload
 (defun planner-diary-insinuate ()
   "Hook Diary into Planner.
 Automatically insert and update a Diary section in day plan files.
 This adds a new key binding to `planner-mode-map':
 C-cC-e updates the diary sections."
   ;; FIXME: update all diary sections: planner-diary-insert-all-diaries-maybe
-  (define-key planner-mode-map "\C-c\C-e" 'planner-diary-insert-all-diaries-maybe)
+  (define-key planner-mode-map "\C-c\C-e"
+    'planner-diary-insert-all-diaries-maybe)
   (add-hook 'planner-goto-hook 'planner-diary-insert-all-diaries-maybe))
 
+;;;###autoload
 (defalias 'planner-insinuate-diary 'planner-diary-insinuate)
 
+;;;###autoload
 (defun planner-diary-add-entry (date time text)
   "Prompt for a diary entry to add to `diary-file' on DATE.
 Uses `planner-annotation-functions' to make hyperlinks.
 TIME and TEXT are used in the description."
-  (interactive (list (planner-read-date)
-		     (read-string "Time: ")
+  (interactive (list (planner-read-date nil t)
+                     (read-string "Time: ")
                      (read-string "Diary entry: ")))
   (save-window-excursion
     (make-diary-entry
