@@ -1,9 +1,27 @@
 ;;; planner-experimental.el --- Experimental functions for Emacs planner mode
-;;; Experimental functions for planner.el
+
+;; Copyright (C) 2004 Free Software Foundation, Inc.
+
+;; Author: Sacha Chua
+
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
-;;
-;; Version: 3.30
 
 (require 'planner)
 
@@ -18,8 +36,8 @@
       (progn
         (set-buffer planner-search-notes-buffer)
         (forward-line -1)
-        (goto-char (line-beginning-position))
-        (emacs-wiki-follow-name-at-point))
+        (goto-char (planner-line-beginning-position))
+        (planner-follow-name-at-point))
     (error "No current search.")))
 
 (defun planner-search-notes-previous-match ()
@@ -29,8 +47,8 @@
       (progn
         (set-buffer planner-search-notes-buffer)
         (forward-line 1)
-        (goto-char (line-beginning-position))
-        (emacs-wiki-follow-name-at-point))
+        (goto-char (planner-line-beginning-position))
+        (planner-follow-name-at-point))
     (error "No current search.")))
 
 ;;;_* Tasks
@@ -48,7 +66,7 @@
                date
                found
                (start (match-beginning 0)))
-          (goto-char (line-beginning-position))
+          (goto-char (planner-line-beginning-position))
           (save-excursion
             (unless on-date
               (while (planner-find-task task-info (point))
@@ -63,8 +81,8 @@
             (if (string= keep
                          (planner-task-date (planner-current-task-info)))
                 (if found
-                    (delete-region (line-beginning-position)
-                                   (min (1+ (line-end-position))
+                    (delete-region (planner-line-beginning-position)
+                                   (min (1+ (planner-line-end-position))
                                         (point-max)))
                   (setq found t)
                   (forward-line 1))
