@@ -1,37 +1,33 @@
 ;;; planner-export-diary.el --- Diary export for the Emacs Planner
 
-;; Copyright (C) 2001 John Wiegley <johnw@gnu.org>
-;; Parts copyright (C) 2004 Sandra Jean Chua <sacha@free.net.ph>
+;; Copyright (C) 2001, 2004 Free Software Foundation, Inc.
 ;; Parts copyright (C) 2004 Xin Wei Hu (huxw AT knight DOT 6test DOT edu DOT cn)
 
 ;; Emacs Lisp Archive Entry
 ;; Filename: planner-export-diary.el
-;; Version: 3.30
 ;; Keywords: hypermedia
 ;; Author: John Wiegley <johnw@gnu.org>
-;; Maintainer: Sacha Chua <sacha@free.net.ph>
 ;; Description: Use Emacs for life planning
-;; URL: http://sacha.free.net.ph/notebook/emacs/stable/planner/planner-export.el
-;; ChangeLog: http://sacha.free.net.ph/notebook/emacs/stable/planner/ChangeLog
-;; Compatibility: Emacs20, Emacs21
+;; URL: http://www.plannerlove.com/
+;; Compatibility: Emacs20, Emacs21, XEmacs21
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
-;;
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
+
 ;;; Commentary:
 
 ;; Use this package if you want to export diary entries from your
@@ -59,8 +55,12 @@
 ;; on `planner-export-diary-future' and
 ;; `planner-export-diary-get-schedule-entries'.
 
+;; Yann Hodique helped port this to Muse.
+
 ;;; Code:
 
+(require 'planner)
+
 (defvar planner-export-diary-file "~/diary.planner"
   "*Name of the file into which schedules are exported from planner.
 This file will be automatically overwritten every time planner
@@ -69,6 +69,7 @@ entries are exported, so be careful.")
 (defvar planner-export-diary-number-of-days 3
   "*Number of days to export diary appointments for.")
 
+;;;###autoload
 (defun planner-export-diary-future ()
   "Exports only `planner-export-number-of-days' days of entries.
 This function can be put into your `after-save-hook'."
@@ -78,6 +79,7 @@ This function can be put into your `after-save-hook'."
                          (planner-today)
                          (1- planner-export-diary-number-of-days))))
 
+;;;###autoload
 (defun planner-export-diary-setup ()
   "Add `planner-export-diary-future' to `after-save-hook' in planner buffers.
 You can add this function to `planner-mode-hook'."
@@ -88,13 +90,13 @@ You can add this function to `planner-mode-hook'."
 (defun planner-export-diary-get-schedule-entries (files)
   "Return a list containing the planner schedule entries in FILES.
 Entries in the returned list are of the form [DATE START END
-DATA].  FILES is a list of planner pages."
+DATA].  FILES is an alist of planner pages and their filenames."
   (with-temp-buffer
-    (cd planner-directory)
+    (cd (planner-directory))
     (let ((list '())
           start end data)
       (while (car files)
-        (insert-file-contents (car files))
+        (insert-file-contents (cdar files))
         (goto-char (point-min))
         (while (re-search-forward
                 "^\\s-*\\([0-9]+:[0-9]+\\)\\s-*|\\s-*\\(.+\\)" nil t)
@@ -105,7 +107,7 @@ DATA].  FILES is a list of planner pages."
             (setq end (match-string 1 data))
             (setq data (replace-match "" nil t data)))
           (setq list (cons
-                      (vector (car files)
+                      (vector (caar files)
                               start end data)
                       list)))
         (setq files (cdr files))
@@ -129,6 +131,7 @@ DATA]."
                 (elt item 3)))
              list "\n"))
 
+;;;###autoload
 (defun planner-export-diary (&optional from to)
   "Exports all the schedules or the ones from FROM to TO (inclusive)."
   (interactive)
