@@ -1,9 +1,27 @@
 ;;; planner-id.el --- planner.el extension for global task IDs
-;;
-;; Copyright (C) 2003 Sacha Chua <sacha@free.net.ph>
-;; Version: 3.30
-;; URL: http://sacha.free.net.ph/notebook/emacs/dev/planner/
-;;
+
+;; Copyright (C) 2003, 2004, 2005 Free Software Foundation, Inc.
+
+;; Author: Sacha Chua <sacha@free.net.ph>
+;; URL: http://www.plannerlove.com/
+
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
+
 ;;; Commentary:
 ;;
 ;; After loading planner.el, place planner-id.el in your load path
@@ -25,14 +43,15 @@
 ;; task descriptions, you may find M-x planner-edit-task-description
 ;; easier to use. Other changes (A/B/C, status) can be applied with
 ;; M-x planner-update-task after you edit the buffer.
-;;
-;; You can get planner.el from
-;; http://sacha.free.net.ph/notebook/emacs/dev/planner/
-;;
-;; Contributors:
-;; - Oliver Krause <oik@gmx.net>
-;;   Main idea, testing
 
+;;; Contributors:
+
+;; Oliver Krause <oik@gmx.net>: Main idea, testing.
+
+;; Jim Ottaway provided a fix for interaction of task IDs with
+;; multiple links, as well as a regexp bug.
+
+;; Yann Hodique helped port this to Muse.
 
 (require 'planner)
 
@@ -67,46 +86,59 @@
 (defvar planner-id-values nil
   "Alist with (key nextvalue) pairs.")
 
-(defvar planner-id-regexp "{{\\([^:]+\\):\\([0-9]+\\)}}"
+(defvar planner-id-regexp "{{\\([^:\n]+\\):\\([0-9]+\\)}}"
   "Regexp matching planner IDs.")
 
-(defun planner-id-get-id-from-string (string)
-  "Return the planner ID in STRING as (identifier number)."
-  (when (string-match planner-id-regexp string)
-    (cons (match-string-no-properties 1 string)
-          (match-string-no-properties 2 string))))
+(defun planner-id-get-id-from-string (string &optional key)
+  "Return the planner ID in STRING as (identifier number).
+If KEY is specified, match against that."
+  (when (string-match
+         (concat "{{\\("
+                 (or key "[^:\n]+")
+                 "\\):\\([0-9]+\\)}}") string)
+    (cons (planner-match-string-no-properties 1 string)
+          (planner-match-string-no-properties 2 string))))
 
 (defun planner-id-get-current-id ()
   "Return the planner ID on the current line as (identifier number)."
-  (planner-id-get-id-from-string (buffer-substring (line-beginning-position)
-                                                   (line-end-position))))
+  (planner-id-get-id-from-string
+   (buffer-substring (planner-line-beginning-position)
+                     (planner-line-end-position))))
 
 (defun planner-id-format-as-string (id)
   "Return the planner ID as a string of the form {{identifier:number}}."
   (concat "{{" (car id) ":" (cdr id) "}}"))
 
-(defun planner-id-find-task (task-info &optional point) 
-  "Find task described by TASK-INFO. If POINT is non-nil, start from there. 
-If task is found, move point to line beginning and return non-nil. 
-If task is not found, leave point at POINT or the start of the buffer 
-and return nil." 
-  (goto-char (or point (point-min))) 
-  (let ((task-id (planner-id-get-id-from-string 
-                  (planner-task-description task-info))) 
-        (found nil)) 
-    (while (and (not found)
-		(search-forward 
-                 (if task-id 
-                     (planner-id-format-as-string task-id) 
-                   (planner-task-description task-info)) 
-                 nil t))
-      (when (string-match planner-task-regexp  
-                          (buffer-substring (line-beginning-position) 
-                                            (line-end-position))) 
-        (setq found t))) 
-    (when found (goto-char (line-beginning-position))))) 
+;;;###autoload
+(defun planner-id-find-task (task-info &optional point)
+  "Find task described by TASK-INFO. If POINT is non-nil, start from there.
+If task is found, move point to line beginning and return non-nil.
+If task is not found, leave point at POINT or the start of the buffer
+and return nil."
+  (goto-char (or point (point-min)))
+  (let ((task-id
+         (cond
+          ;; Task ID
+          ((listp task-info)
+           (planner-id-get-id-from-string
+            (planner-task-description task-info)))
+          ;; Just the ID
+          ((numberp task-info)
+           (cons "Tasks" (number-to-string task-info)))
+          ;; ID as string
+          ((stringp task-info) (cons "Tasks" task-info))))
+        (found nil))
+    (when (re-search-forward
+           (concat planner-task-regexp ".*"
+                   (regexp-quote
+                    (if task-id
+                        (planner-id-format-as-string task-id)
+                      (planner-task-description task-info))))
+           nil t)
+      (goto-char (planner-line-beginning-position)))))
 
 ;;; Redeclaration
+;;;###autoload
 (defun planner-id-jump-to-linked-task (&optional info)
   "Display the linked task page.
 If INFO is specified, follow that task instead."
@@ -151,6 +183,7 @@ If INFO is specified, follow that task instead."
        (message "Could not read planner-id-values from %s. Setting it to nil."
                 planner-id-tracking-file)))))
 
+;;;###autoload
 (defun planner-id-add-task-id-maybe ()
   "Add task ID if `planner-id-add-task-id-flag' is non-nil."
   (when planner-id-add-task-id-flag
@@ -175,19 +208,21 @@ Completed or cancelled tasks are not updated. This can be added
 to `write-file-functions' (CVS Emacs) or `write-file-hooks'.
 If FORCE is non-nil, completed and cancelled tasks are also updated."
   (interactive (list current-prefix-arg))
-  (save-excursion
-    (goto-char (point-min))
-    (while (re-search-forward
-            (concat
-             (if force
-                 planner-task-regexp
-               planner-live-task-regexp)
-             "\\(.*?\\){{Tasks:[0-9]+}}")
-            nil t)
-      (planner-update-task)
-      ;; Force the next line to be considered even if
-      ;; planner-multi-update-task kicked in.
-      (forward-line 1)))
+  ;; Prevent planner-id updates from cascading
+  (let ((planner-id-update-automatically nil))
+    (with-planner-update-setup
+     (goto-char (point-min))
+     (while (re-search-forward
+             (concat
+              (if force
+                  planner-task-regexp
+                planner-live-task-regexp)
+              ".*?{{Tasks:[0-9]+}}")
+             nil t)
+       (planner-update-task)
+       ;; Force the next line to be considered even if
+       ;; planner-multi-update-task kicked in.
+       (forward-line 1))))
   nil)
 
 (defun planner-id-remove-tasks-on-page ()
@@ -208,7 +243,6 @@ Update the linked page, if any."
     (goto-char (point-min))
     (while (re-search-forward planner-task-regexp nil t)
       (planner-id-add-task-id))
-    ;; Force refontification
     (font-lock-fontify-buffer)))
 
 (defun planner-id-at-point (&optional pos)
@@ -221,9 +255,9 @@ Update the linked page, if any."
         (save-excursion
           (goto-char here)
           (skip-chars-backward " \t\n")
-          (or (looking-at "{{Tasks:[^}]+}}")
-              (and (search-backward "{{" (line-beginning-position) t)
-                   (looking-at "{{Tasks:[^}]+}}"))
+          (or (looking-at "{{Tasks:[^}\n]+}}")
+              (and (search-backward "{{" (planner-line-beginning-position) t)
+                   (looking-at "{{Tasks:[^}\n]+}}"))
               (<= here (match-end 0)))))))
 
 (eval-and-compile
@@ -238,7 +272,7 @@ Update the linked page, if any."
   (grep (concat (or grep-command  "grep") " "
                 (shell-quote-argument id) " "
                 (shell-quote-argument
-                 (expand-file-name planner-directory)) "/*")))
+                 (expand-file-name (planner-directory))) "/*")))
 
 (defun planner-id-follow-id-at-point ()
   "Display a list of all pages containing the ID at point."
@@ -282,11 +316,12 @@ EVENT is the mouse event."
 ;;     map)
 ;;   "Local keymap used by planner when on an ID.")
 
+;;;###autoload
 (defun planner-id-markup (beg end &optional verbose)
   "Highlight IDs as unobtrusive, clickable text from BEG to END.
 VERBOSE is ignored."
   (goto-char beg)
-  (while (re-search-forward "{{[^}]+}}" end t)
+  (while (re-search-forward "{{[^}\n]+}}" end t)
     (planner-highlight-region
      (match-beginning 0)
      (match-end 0)
@@ -297,20 +332,22 @@ VERBOSE is ignored."
       ;;'keymap planner-id-keymap
       ))))
 
+;;;###autoload
 (defun planner-id-update-tasks-maybe ()
   "Update tasks depending on the value of `planner-id-update-automatically'."
   (when planner-id-update-automatically
     (planner-id-update-tasks-on-page)))
 
+;;;###autoload
 (defun planner-id-setup ()
   "Hook into `planner-mode'."
-  (add-hook 'emacs-wiki-highlight-buffer-hook
-            'planner-id-markup nil t)
+  (add-hook 'muse-colors-buffer-hook
+            'planner-id-markup t t)
   (add-hook
    (if (and (boundp 'write-file-functions)
             (not (featurep 'xemacs)))
        'write-file-functions
-     'local-write-file-hooks)
+     'write-file-hooks)
    'planner-id-update-tasks-maybe nil t))
 
 (add-hook 'planner-mode-hook 'planner-id-setup)
@@ -318,6 +355,10 @@ VERBOSE is ignored."
 (setq planner-jump-to-linked-task-function 'planner-id-jump-to-linked-task)
 (setq planner-find-task-function 'planner-id-find-task)
 
+(eval-after-load "planner-publish"
+  '(add-to-list 'planner-publish-markup-regexps
+                '(1270 planner-id-regexp 0 "")))
+
 (provide 'planner-id)
 
 ;;; planner-id.el ends here
