@@ -1,32 +1,32 @@
 ;;; planner-notes-index.el --- Note indexing support for the Emacs planner
 
+;; Copyright (C) 2004, 2005 Free Software Foundation, Inc.
+
 ;;; Commentary:
 
 ;;;_+ Package description
 
-;; Copyright (C) 2004 Sandra Jean Chua <sacha@free.net.ph>
+;; Author: Sandra Jean Chua <sacha@free.net.ph>
 ;; Filename: planner-notes-index.el
-;; Version: 3.30
-;; URL: http://sacha.free.net.ph/notebook/emacs/emacs-wiki/
-;; URL: http://sacha.free.net.ph/notebook/wiki/PlannerMode.php
+;; URL: http://www.plannerlove.com/
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
-;;
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
+
 ;;;_+ Usage
 ;;
 ;; Place planner-notes-index.el in your load path and add this to your
@@ -72,7 +72,10 @@
 ;; the appropriate <planner-notes-index> tags. You can also use
 ;; planner-extract-note-headlines in your own functions.
 
-(require 'emacs-wiki)
+;;;_+ Contributors
+
+;; Yann Hodique helped port this to Muse.
+
 (require 'planner)
 (require 'calendar)
 
@@ -92,9 +95,7 @@
 If LIMIT is non-nil, only that many headlines are returned."
   (when (stringp limit) (setq limit (string-to-number limit)))
   (with-temp-buffer
-    (insert-file-contents (expand-file-name
-                           page
-                           planner-directory))
+    (insert-file-contents (planner-page-file page))
     (planner-notes-get-headlines limit)))
 
 (defun planner-notes-index-headlines-in-range (&optional from to limit)
@@ -102,23 +103,18 @@ If LIMIT is non-nil, only that many headlines are returned."
 FROM (inclusive) and TO (inclusive) limit the dates. If FROM is
 nil, start from the earliest entry. If TO is nil, include the
 last entry. If LIMIT is non-nil, return at most LIMIT entries."
-  (with-emacs-wiki-project planner-project
+  (with-planner
     (when (and limit (stringp limit)) (setq limit (string-to-number limit)))
-    (let ((pages
-           (reverse (directory-files planner-directory nil planner-date-regexp)))
+    (let ((pages (mapcar 'car (planner-get-day-pages from to)))
           data
           headlines)
       (while (and pages (if limit (> limit 0) t))
-        (unless (or
-                 (if from (string< (car pages) from))
-                 (if to (and (not (string< (car pages) to))
-			     (not (string= (car pages) to)))))
-          (setq data (planner-notes-index-headlines-on-page (car pages) limit))
-          (when limit
-            (setq limit (- limit (length data))))
-          (when data
-            (add-to-list 'headlines
-                         (cons (car pages) data) t)))
+        (setq data (planner-notes-index-headlines-on-page (car pages) limit))
+        (when limit
+          (setq limit (- limit (length data))))
+        (when data
+          (add-to-list 'headlines
+                       (cons (car pages) data) t))
         (setq pages (cdr pages)))
       headlines)))
 
@@ -134,14 +130,16 @@ If SUFFIX is non-nil, it is appended to the item."
     (setq page-headlines (cdr page-headlines))
     (while (and page-headlines (if limit (> limit 0) t))
       (when prefix (insert prefix))
-      (insert (emacs-wiki-make-link (concat page (caar page-headlines))
-                                    (cdr (car page-headlines))))
+      (insert (planner-make-link (concat page (caar page-headlines))
+				 (cdr (car page-headlines))
+				 t))
       (when suffix (insert suffix))
       (setq page-headlines (cdr page-headlines))
       (when limit (setq limit (1- limit))))))
 
 ;;;_* Emacs-wiki tags
 
+;;;###autoload
 (defun planner-notes-index-tag (tag-beg tag-end attrs)
   "Mark up planner-notes-index tags.
 
@@ -164,7 +162,7 @@ Tags can be of the form:
            (insert "** " last-year "."
                    (setq last-month (match-string 2 (car item))) "\n\n")))
        (insert "*** " (car item) "\n\n")
-       (planner-notes-index-insert-as-list item nil "- " "\n")
+       (planner-notes-index-insert-as-list item nil " - " "\n")
        (insert "\n"))
      (if (assoc "page" attrs)
          (cons (cdr (assoc "page" attrs))
@@ -176,6 +174,7 @@ Tags can be of the form:
         (cdr (assoc "to" attrs))
         (cdr (assoc "limit" attrs)))))))
 
+;;;###autoload
 (defun planner-notes-index-month-table-tag (beg end attrs)
   "Mark up a month note index.  Tag is from BEG to END.
 ATTRS is a list of attributes. \"Month\" is a yyyy.mm
@@ -236,6 +235,7 @@ Examples:
 (defvar planner-notes-index-buffer "*Notes Index*"
   "Buffer for planner note index.")
 
+;;;###autoload
 (defun planner-notes-index (&optional from to limit)
   "Display a clickable notes index.
 If called from a Lisp program, display only dates between FROM
@@ -247,13 +247,11 @@ P")
   (when limit (setq limit (prefix-numeric-value limit)))
   (let ((headlines
          (planner-notes-index-headlines-in-range from to limit))
-        last-month last-year
-        (emacs-wiki-project planner-project))
+        last-month last-year)
     (with-current-buffer (get-buffer-create planner-notes-index-buffer)
       (setq buffer-read-only nil)
       (erase-buffer)
-      (cd planner-directory)
-      (emacs-wiki-change-project planner-project)
+      (cd (planner-directory))
       (mapcar (lambda (item)
                 (when (string-match planner-date-regexp (car item))
                   (unless (and last-year
@@ -267,13 +265,14 @@ P")
                           (setq last-month
                                 (match-string 2 (car item))) "\n\n")))
                 (insert "*** " (car item) "\n\n")
-                (planner-notes-index-insert-as-list item nil "- " "\n")
+                (planner-notes-index-insert-as-list item nil " - " "\n")
                 (insert "\n"))
               headlines)
       (planner-mode)
       (goto-char (point-min))
       (pop-to-buffer (current-buffer)))))
 
+;;;###autoload
 (defun planner-notes-index-days (days)
   "Display an index of notes posted over the past few DAYS.
 The list ends with the day of the current buffer or `planner-today'."
@@ -284,6 +283,7 @@ The list ends with the day of the current buffer or `planner-today'."
     (planner-get-current-date-filename) (- 1 days))
    (planner-get-current-date-filename)))
 
+;;;###autoload
 (defun planner-notes-index-weeks (weeks)
   "Display an index of notes posted over the past few WEEKS.
 The list ends with the week of the current buffer or `planner-today'.
@@ -300,6 +300,7 @@ Weeks start from Sunday."
                    (elt date 0) (elt date 2)))
      (planner-get-current-date-filename))))
 
+;;;###autoload
 (defun planner-notes-index-months (months)
   "Display an index of notes posted over the past few MONTHS.
 The list ends with the month of the current buffer or `planner-today'."
@@ -314,8 +315,9 @@ The list ends with the month of the current buffer or `planner-today'."
                       months -1) (elt date 2)))
      (planner-get-current-date-filename))))
 
+;;;###autoload
 (defun planner-notes-index-years (years)
-  "Display an index of notes posted over the past few MONTHS.
+  "Display an index of notes posted over the past few YEARS.
 The current year is included."
   (interactive (list (read-string "Number of years (1): " nil nil "1")))
   (when (stringp years) (setq years (string-to-number years)))
