@@ -1,33 +1,38 @@
 ;;; planner-rdf.el --- RDF export for Emacs PlannerMode
 
-;; Copyright 2004 Rainer Volz
-;;
+;; Copyright (C) 2004 Rainer Volz
+;; Parts copyright (C) 2005 Free Software Foundation, Inc.
+
 ;; Author: Rainer Volz, http://www.rainervolz.de
 ;; Version: 0.1
 ;; Keywords: PlannerMode OWL RDF
 ;; X-URL: not distributed yet
 
-;; This program is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
 ;; the Free Software Foundation; either version 2, or (at your option)
 ;; any later version.
-;;
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
-;;
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
+
 ;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
-;; planner-rdf is an add-on to GNU Emacs PlannerMode. It provides functions to
-;; publish Planner information in RDF format, so that the Planner information
-;; can be processed in an automated way by RDF-aware tools. To do this
-;; planner-rdf adds itself to the hook emacs-wiki-after-file-publish-hook,
-;; which is run whenever Planner pages are being published.
+;; planner-rdf is an add-on to Planner. It provides functions to
+;; publish Planner information in RDF format, so that the Planner
+;; information can be processed in an automated way by RDF-aware
+;; tools. To do this planner-rdf adds itself to the hook
+;; muse-after-publish-hook, which is run whenever Planner pages are
+;; being published.
 
 ;; The source distribution and the HTML edition of the documentation is
 ;; available at http://www.rainervolz.de/planner-rdf/
@@ -35,18 +40,18 @@
 ;; To use planner-rdf put this file into your load-path and the following into
 ;; your ~/.emacs file:
 ;;   (require 'planner-rdf)
-;;   (add-hook 'emacs-wiki-after-file-publish-hook 'planner-rdf-publish-file)
-;;   (add-hook 'emacs-wiki-after-wiki-publish-hook 'planner-rdf-publish-index)
+;;   (add-hook 'muse-after-publish-hook 'planner-rdf-publish-file)
+;;   (add-hook 'muse-after-publish-hook 'planner-rdf-publish-index)
 
 ;; To minimise interference with the publication of other (non-Planner)
-;; emacs-wiki projects, planner-rdf-publish-file checks whether the current
+;; Muse projects, planner-rdf-publish-file checks whether the current
 ;; major mode is planner-mode. If yes, RDF publication is started, if not, the
 ;; file is ignored.
 
 ;; planner-rdf creates two files for every published Planner file: a .rdf and
-;; a .owl file. The .owl file contains 
-;; - tasks 
-;; - notes 
+;; a .owl file. The .owl file contains
+;; - tasks
+;; - notes
 ;; of the respective Planner page in OWL format. The OWL schema used is
 ;; documented in planner-rdf.owl, which is part of this distribution.
 ;; For a detailed explanation of the format please look at the planner-rdf
@@ -101,7 +106,7 @@
   "{{Tasks:\\([0-9]+\\)}}" 
   "Finds task ids of the form {{Tasks:<Number>}} in Planner tasks.")
 (defvar planner-rdf-matchstr-ptask
-  "^#\\([A-C]\\)\\([0-9]*\\)\\s-*\\([_oX>CP]\\)\\s-*\\(.+\\)$"
+  "^#\\([A-C]\\)\\([0-9]*\\)\\s-*\\([_oXDCP]\\)\\s-*\\(.+\\)$"
   "Finds a Planner task in a buffer.")
 
 ;; common match strings - notes
@@ -126,10 +131,10 @@
 
 ;; common match strings - links
 (defvar planner-rdf-matchstr-plink1
-  "\\[\\[\\([^[]+?\\)\\]\\[\\(.+?\\)\\]\\]"
+  "\\[\\[\\([^[\n]+?\\)\\]\\[\\(.+?\\)\\]\\]"
   "Link like [[<link>][<text>]]. Match link and text.")
 (defvar planner-rdf-matchstr-plink2
-  "\\[\\[\\([^[]+?\\)\\]\\]"
+  "\\[\\[\\([^[\n]+?\\)\\]\\]"
   "Link like [[<link>]]. Match link.")
 
 (defvar planner-rdf-matchstr-pagenotelink
@@ -194,7 +199,7 @@ Output must be to the current buffer, and in Turtle syntax.")
 (defun planner-rdf-get-taskid (taskdesc)
   "Retrieve or generate a task id from the description."
   (if (string-match planner-rdf-matchstr-ptaskids taskdesc)
-		(match-string-no-properties 1 taskdesc)
+		(planner-match-string-no-properties 1 taskdesc)
 	 (concat "-" (number-to-string(abs (sxhash taskdesc))))))
 
 (defun planner-rdf-get-task-info ()
@@ -243,8 +248,8 @@ Output must be to the current buffer, and in Turtle syntax.")
 					 ;; (planner-rdf-log (concat "Note " curr-note-id " " curr-note-headline))
 					 (setq curr-note-txt "")
 					 (setq curr-note-id 0)))
-				(setq curr-note-id (match-string-no-properties 1))
-				(setq curr-note-headline (match-string-no-properties 2))
+				(setq curr-note-id (planner-match-string-no-properties 1))
+				(setq curr-note-headline (planner-match-string-no-properties 2))
 				;; zur nächsten - sonst wird der Titel als Text mitgenommen
 				(forward-line)))
 		(if in-notes
@@ -334,7 +339,7 @@ custom content."
 (defun planner-rdf-replace-links (input)
   "replace Planner-style links, [[link][text]] or [...], with text."
   (while (not (null (string-match planner-rdf-matchstr-plink1 input 0)))
-	 (setq input (replace-match (match-string-no-properties 2 input) t t input)))
+	 (setq input (replace-match (planner-match-string-no-properties 2 input) t t input)))
   (while (not (null (string-match planner-rdf-matchstr-plink2 input 0)))
 	 (setq input (replace-match "*link*" t t input)))
   input)
@@ -470,13 +475,13 @@ of the standard output to provide customised content."
 	 (cond
 	  ;; title with time and day page link
 	  ((string-match planner-rdf-matchstr-pnote1 input)
-		(setq title (planner-rdf-escape-string(match-string-no-properties 1 input))))
+		(setq title (planner-rdf-escape-string(planner-match-string-no-properties 1 input))))
 	  ;; title with time and project page link
 	  ((string-match planner-rdf-matchstr-pnote2 input)
-		(setq title (planner-rdf-escape-string(match-string-no-properties 1 input))))
+		(setq title (planner-rdf-escape-string(planner-match-string-no-properties 1 input))))
 	  ;; title with time, no page link
 	  ((string-match planner-rdf-matchstr-pnote3 input)
-		(setq title (planner-rdf-escape-string (match-string-no-properties 1 input))))
+		(setq title (planner-rdf-escape-string (planner-match-string-no-properties 1 input))))
 	  ;; ok, take evrything
 	  (t (setq title (planner-rdf-escape-string input))))
 	 (setq title (planner-rdf-replace-links title))
@@ -489,10 +494,10 @@ of the standard output to provide customised content."
 	 (cond
 	  ;; title with time and day page link
 	  ((string-match planner-rdf-matchstr-pnote4 input)
-		(setq alias (planner-rdf-escape-string(match-string-no-properties 1 input))))
+		(setq alias (planner-rdf-escape-string(planner-match-string-no-properties 1 input))))
 	  ;; title with time and project page link
 	  ((string-match planner-rdf-matchstr-pnote5 input)
-		(setq alias (planner-rdf-escape-string(match-string-no-properties 1 input))))
+		(setq alias (planner-rdf-escape-string(planner-match-string-no-properties 1 input))))
 	  ;; ok, nothing there
 	  (t (setq alias "")))
 	 (planner-rdf-replace-sth alias "#" "-")))
@@ -504,9 +509,9 @@ of the standard output to provide customised content."
 	 (cond
 	  ;; there is something
 	  ((string-match planner-rdf-matchstr-pagenotelink alias)
-		(setq plan (planner-rdf-escape-string(match-string-no-properties 1 alias))))
+		(setq plan (planner-rdf-escape-string(planner-match-string-no-properties 1 alias))))
 	  ((string-match planner-rdf-matchstr-pagenotelink1 alias)
-		(setq plan (planner-rdf-escape-string(match-string-no-properties 1 alias))))
+		(setq plan (planner-rdf-escape-string(planner-match-string-no-properties 1 alias))))
 	  ;; ok, nothing there
 	  (t (setq plan page)))
 	 plan))
@@ -557,7 +562,7 @@ of the standard output to provide customised content."
 				(insert 
 				 "\t<date>" 
 				 (planner-rdf-replace-sth 
-				  (match-string-no-properties 1 (elt notevector 2)) "." "-") 
+				  (planner-match-string-no-properties 1 (elt notevector 2)) "." "-") 
 				 "</date>\n"))))
 
 	 ;; find time
@@ -565,9 +570,9 @@ of the standard output to provide customised content."
 							 (elt notevector 2))
 		  (insert 
 			"\t<note-time>" 
-			(if (match-string-no-properties 1 (elt notevector 2))
-				 (match-string-no-properties 1 (elt notevector 2))
-			  (match-string-no-properties 2 (elt notevector 2)))
+			(if (planner-match-string-no-properties 1 (elt notevector 2))
+				 (planner-match-string-no-properties 1 (elt notevector 2))
+			  (planner-match-string-no-properties 2 (elt notevector 2)))
 			":00</note-time>\n"))
 	 (insert "\t<description>" title "</description>\n")	 
 	 (when (not (string= "" alias))
@@ -650,14 +655,15 @@ of the standard output to provide customised content."
   )
 )
 
+;;;###autoload
 (defun planner-rdf-publish-file (file)
   "Publish the file in RDF format, if called by PlannerMode.
-Designed to be called via the emacs-wiki-after-file-publis-hook.
-Non-Planner files, matching emacs-wiki-image-regexp will be treated 
+Designed to be called via `muse-after-publish-hook'.
+Non-Planner files, matching `muse-image-regexp' will be treated
 differently. Currently they are simply ignored."
   (interactive "f")
   (when (eq major-mode 'planner-mode)
-	 (if (string-match emacs-wiki-image-regexp file)
+	 (if (string-match muse-image-regexp file)
 			(message (concat "planner-rdf: Ignored file " file))
 		(let ((tasks nil)
 				(notes nil))
@@ -702,9 +708,10 @@ differently. Currently they are simply ignored."
 			 (kill-buffer mybuff3))
 		  ))))
 
+;;;###autoload
 (defun planner-rdf-publish-index ()
   "Create an index for the .rdf files.
-Will be called via the emacs-wiki-after-wiki-publish-hook.
+Will be called via `muse-after-publish-hook'.
 Creates index.rdf, a rdf:bag, with all existing .rdf files as
 items."
   (interactive)
