@@ -1,40 +1,38 @@
 ;;; planner-rmail.el --- RMAIL support for Planner, an organizer for Emacs
 
+;; Copyright (C) 2004, 2006 Free Software Foundation, Inc.
+;; Parts copyright (C) 2004 Frederik Fouvry
+
 ;;; Commentary:
 ;;
 ;;;_* Commentary
 
 ;;;_ + Package description
 
-;; Copyright (C) 2004 Sandra Jean Chua <sacha@free.net.ph>
-
 ;; Emacs Lisp Archive Entry
-;; Filename: planner.el
-;; Version: 3.30
+;; Filename: planner-rmail.el
 ;; Keywords: hypermedia
 ;; Author: John Wiegley <johnw@gnu.org>
-;; Maintainer: Sacha Chua <sacha@free.net.ph>
 ;; Description: Use Emacs for life planning
-;; URL: http://sacha.free.net.ph/notebook/emacs/planner/planner.el
-;; ChangeLog: http://sacha.free.net.ph/notebook/emacs/planner/ChangeLog
-;; Compatibility: Emacs20, Emacs21
+;; URL: http://www.plannerlove.com/
+;; Compatibility: Emacs20, Emacs21, XEmacs21
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;;_ + Usage
 
@@ -58,6 +56,30 @@
 (require 'rmail)
 
 ;;; Code:
+
+;; This isn't provided in XEmacs
+(defun planner-rmail-narrow-to-non-pruned-header ()
+  "Narrow to the whole (original) header of the current message."
+  (if (fboundp 'rmail-narrow-to-non-pruned-header)
+      (rmail-narrow-to-non-pruned-header)
+    (let (start end)
+      (narrow-to-region (rmail-msgbeg rmail-current-message) (point-max))
+      (goto-char (point-min))
+      (forward-line 1)
+      (if (= (following-char) ?1)
+          (progn
+            (forward-line 1)
+            (setq start (point))
+            (search-forward "*** EOOH ***\n")
+            (setq end (match-beginning 0)))
+        (forward-line 2)
+        (setq start (point))
+        (search-forward "\n\n")
+        (setq end (1- (point))))
+      (narrow-to-region start end)
+      (goto-char start))))
+
+
 ;;;###autoload
 (defun planner-rmail-annotation-from-mail ()
   "Return an annotation for the current message.
@@ -65,8 +87,8 @@ This function can be added to `planner-annotation-functions'."
   (when (eq major-mode 'rmail-mode)
     (save-excursion
       (save-restriction
-        (rmail-narrow-to-non-pruned-header)
-        (emacs-wiki-make-link
+        (planner-rmail-narrow-to-non-pruned-header)
+        (planner-make-link
          (concat "rmail://" (buffer-file-name) "/" (mail-fetch-field "message-id"))
          (if (and planner-ignored-from-addresses
                   (string-match planner-ignored-from-addresses
@@ -74,12 +96,13 @@ This function can be added to `planner-annotation-functions'."
              (concat "E-mail to " (planner-get-name-from-address
                                    (mail-fetch-field "to")))
            (concat "E-mail from " (planner-get-name-from-address
-                                   (mail-fetch-field "from")))))))))
+                                   (mail-fetch-field "from"))))
+	 t)))))
 
 ;;;###autoload
 (defun planner-rmail-browse-url (url)
   "If this is an RMAIL URL, jump to it."
-  (when (string-match "^rmail://\\(.+\\)/\\(.+?\\)$" url)
+  (when (string-match "\\`rmail://\\(.+\\)/\\(.+?\\)$" url)
     (let ((message-id (match-string 2 url))
           (file (match-string 1 url))
           message-number)
@@ -102,7 +125,7 @@ This function can be added to `planner-annotation-functions'."
             message-number)
         (error "Message not found")))))
 
-(planner-add-protocol "rmail" 'planner-rmail-browse-url nil)
+(planner-add-protocol "rmail://" 'planner-rmail-browse-url nil)
 (add-hook 'planner-annotation-functions 'planner-rmail-annotation-from-mail)
 (custom-add-option 'planner-annotation-functions
                    'planner-rmail-annotation-from-rmail)
