@@ -1,27 +1,29 @@
 ;;; planner-timeclock-summary-proj.el --- timeclock project for the Emacs planner
 
 ;; Copyright (C) 2004 Pascal Quesseveur
+;; Parts copyright (C) 2005 Free Software Foundation, Inc.
+;; Parts copyright (C) 2005 Trent Buck
 
 ;; Author: Pascal Quesseveur <quesseveur@abaksystemes.fr>
 ;; Time-stamp: <2004-12-17 18:39>
 ;; Description: Summary timeclock of a project
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 ;;
@@ -29,11 +31,22 @@
 ;; files.  That package uses `timeclock-project-alist' and
 ;; `timeclock-seconds-to-string' from timeclock.
 
-;;; To use, call `planner-timeclock-summary-proj-current' from a
-;;; project page. The report is inserted at the current position in
-;;; the buffer. The function
-;;; `planner-timeclock-summary-proj-section' does the same but the
-;;; report is inserted inside a section called "* Report".
+;; To use, call `planner-timeclock-summary-proj-current' from a
+;; project page. The report is inserted at the current position in the
+;; buffer. The function `planner-timeclock-summary-proj-section' does
+;; the same but the report is inserted inside a section called "*
+;; Report".
+
+;; You might want to add
+;;
+;; (planner-timeclock-summary-proj-insinuate)
+;;
+;; to your planner config, which will cause the timeclock summary to
+;; be updated every time a Planner file is written.
+
+;;; Contributors
+
+;; Trent Buck overhauled the code for Planner-Muse.
 
 ;;; CODE
 
@@ -53,45 +66,44 @@
   :type 'integer
   :group 'planner-timeclock-summary)
 
+(defcustom planner-timeclock-summary-proj-header "Report"
+  "Header for the timeclock summary project section in a plan page."
+  :type 'string
+  :group 'planner-timeclock-summary)
+
 ;;;; User variables stop here
 
 (defun planner-timeclock-summary-proj-section ()
-  "Update the current project's time report in the Report section."
+  "Update the secion corresponding with `planner-timeclock-summary-proj-header'
+in the current plan page.
+The section is updated only if it exists."
   (interactive)
   (save-excursion
-    (widen)
-    (goto-char (point-min))
-    (if (re-search-forward "^[*] Report" nil t)
-        ;; A report section has been found in the buffer. We delete it.
-        (progn
-          (forward-line)
-          ;; Delete lines until the next section or to end of buffer.
-          ;; End of buffer is managed by the (catch throw)
-          ;; construct to avoid problems when calling kill-line with
-          ;; point at end of buffer ...
-          (catch 'loop
-            (while (not (looking-at "^[*] "))
-              (if (eobp)
-                  (throw 'loop nil)
-                (kill-line)))))
-      ;; section creation when it doesn't exist
-      (goto-char (point-max))
-      (insert "\n\n* Report\n"))
-    ;; insert the report in the buffer
-    (planner-timeclock-summary-proj-current)
-    (insert "\n\n")))
+    (save-restriction
+      (when (planner-narrow-to-section planner-timeclock-summary-proj-header)
+        (let ((thepage (planner-page-name)))
+          (when (and thepage
+                     ;; Don't edit unless we're in a task page.
+                     (not (string-match planner-date-regexp thepage)))
+            (delete-region (point-min) (point-max))
+            (insert "* " planner-timeclock-summary-proj-header "\n")
+            (planner-timeclock-summary-proj-report thepage)
+            (insert "\n\n")))))))
 
+;;;###autoload
 (defun planner-timeclock-summary-proj-all ()
   "Insert time report for all projects in the current buffer."
   (interactive)
   (planner-timeclock-summary-proj-report nil))
 
+;;;###autoload
 (defun planner-timeclock-summary-proj-current ()
   "Insert time report for the current project in the current buffer."
   (interactive)
-  (let ((project (file-name-nondirectory buffer-file-name)))
+  (let ((project (planner-page-name)))
     (planner-timeclock-summary-proj-report project)))
 
+;;;###autoload
 (defun planner-timeclock-summary-proj-report (project)
   "Insert time report for PROJECT in the current buffer."
   (interactive "sProject: ")
@@ -102,22 +114,29 @@
   "Return time report for PROJ-ALIST.
 The time report is formatted as
 
-  TASK 0 | duration
-  TASK 1 | duration
-   TOTAL | duration."
-  (let ((str)
+  Duration || Task
+  duration | TASK 0
+  duration | TASK 1
+  duration | TOTAL."
+  (let ((str "\n          Duration || Task")
         (total-duration 0))
     (while proj-alist
       (let* ((proj-entry (car proj-alist))
              (duration (cdr proj-entry)))
         (setq str
-              (concat str "\n" (format "%8s" (car proj-entry)) " | "
-                      (planner-timeclock-summary-proj-seconds-to-weekdays-string duration)))
+              (concat str "\n"
+                      (format "%18s" (planner-timeclock-proj-seconds-to-string
+                                      duration))
+                      " | "
+                      (format "%s" (car proj-entry))))
         (setq total-duration (+ duration total-duration))
         (setq proj-alist (cdr proj-alist))))
-    (concat str "\n"
-            (format "%8s" "TOTAL") " | "
-            (planner-timeclock-summary-proj-seconds-to-weekdays-string total-duration) "\n")))
+    (concat str
+            "\n"
+            (format "%18s" (planner-timeclock-proj-seconds-to-string
+                            total-duration))
+            " | "
+            "TOTAL")))
 
 (defun planner-timeclock-proj-make-alist (proj-name)
   "Return an association list for PROJ-NAME.
@@ -147,7 +166,6 @@ project name, and DURATION is the time spent on that project."
             (if (and (< (match-end 0) (length task)) proj-name)
                 (setq task (substring task (match-end 0)))
               (setq task (substring task 0 (match-beginning 0)))))
-        
         ;; record the cons (task . time)
         (if proj-alist
             (let ((proj-time 0)
@@ -175,14 +193,25 @@ If PROJ-NAME is nil, return `timeclock-project-alist'."
         (let* ((proj (car entry-list))
                (proj-entry-name (car proj)))
           (if (and proj-name
-                   (string-match (concat "^" proj-name) proj-entry-name))
+                   (string-match (concat "^\\[\\[" proj-name "\\]\\]")
+                                 proj-entry-name))
               (if projects
                   (add-to-list 'projects proj)
                 (setq projects (list proj))))
           (setq entry-list (cdr entry-list))))
       projects)))
 
-(defun planner-timeclock-summary-proj-seconds-to-weekdays-string (seconds)
+(defun planner-timeclock-summary-proj-insinuate ()
+  "Insinuate planner-timeclock-summary-proj with the rest of Planner."
+  (add-hook 'planner-mode-hook
+            (lambda ()
+              (add-hook
+               (if (boundp 'write-file-functions)
+                   'write-file-functions
+                 'write-file-hooks)
+               'planner-timeclock-summary-proj-section nil t))))
+
+(defun planner-timeclock-proj-seconds-to-string (seconds)
   "Convert the floating point number SECONDS to a string.
 The string is in the form [WWw] [DDd] hh:ss."
   (let* ((workday (* planner-timeclock-workhours-per-day 3600))
