@@ -1,41 +1,37 @@
 ;;; planner-vm.el --- VM support for Planner, an organizer for Emacs
 
+;; Copyright (C) 2004, 2005 Free Software Foundation, Inc.
+
 ;;; Commentary:
 ;;
 ;;;_* Commentary
 
 ;;;_ + Package description
 
-;; Copyright (C) 2004 Sandra Jean Chua <sacha@free.net.ph>
-;; Parts copyright (C) 2004 Jürgen Doser
-
 ;; Emacs Lisp Archive Entry
 ;; Filename: planner.el
-;; Version: 3.30
 ;; Keywords: hypermedia
 ;; Author: John Wiegley <johnw@gnu.org>
-;; Maintainer: Sacha Chua <sacha@free.net.ph>
 ;; Description: Use Emacs for life planning
-;; URL: http://sacha.free.net.ph/notebook/emacs/planner/planner.el
-;; ChangeLog: http://sacha.free.net.ph/notebook/emacs/planner/ChangeLog
+;; URL: http://www.plannerlove.com/
 ;; Compatibility: Emacs20, Emacs21
 
-;; This file is not part of GNU Emacs.
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
-;; This is free software; you can redistribute it and/or modify it under
-;; the terms of the GNU General Public License as published by the Free
-;; Software Foundation; either version 2, or (at your option) any later
-;; version.
-;;
-;; This is distributed in the hope that it will be useful, but WITHOUT
-;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-;; for more details.
-;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;;_ + Usage
 ;;
@@ -55,6 +51,11 @@
 ;; Jürgen Doser (email address unknown) contributed a patch to
 ;; properly open a vm message.
 
+;; Greg Novak provided a message-id bugfix.
+
+;; Fran Burstall provided a patch that turned on annotations in
+;; vm-presentation-mode.
+
 (require 'planner)
 (require 'vm)
 
@@ -71,7 +72,7 @@ This function can be added to `planner-annotation-functions'."
         (set-buffer vm-mail-buffer))
       (when (memq major-mode '(vm-mode vm-presentation-mode))
         (let ((message (car vm-message-pointer)))
-          (emacs-wiki-make-link
+          (planner-make-link
            (concat "vm://"
                    (buffer-file-name
                     (marker-buffer
@@ -86,12 +87,13 @@ This function can be added to `planner-annotation-functions'."
                                      (vm-get-header-contents message "To")))
              (concat "E-mail from "
                      (planner-get-name-from-address
-                      (vm-get-header-contents message "From"))))))))))
+                      (vm-get-header-contents message "From"))))
+	   t))))))
 
 ;;;###autoload
 (defun planner-vm-browse-url (url)
   "If this is an VM URL, jump to it."
-  (when (string-match "^vm://\\(.+\\)/\\([^/]+\\)$" url)
+  (when (string-match "\\`vm://\\(.+\\)/\\([^/\n]+\\)$" url)
     (let ((message-id (match-string 2 url))
           (inbox (match-string 1 url)))
       ; open the inbox read-only
@@ -110,7 +112,7 @@ This function can be added to `planner-annotation-functions'."
             (setq mp (cdr mp))))
         t))))
 
-(planner-add-protocol "vm" 'planner-vm-browse-url nil)
+(planner-add-protocol "vm://" 'planner-vm-browse-url nil)
 (add-hook 'planner-annotation-functions 'planner-vm-annotation-from-mail)
 (custom-add-option 'planner-annotation-functions
                    'planner-vm-annotation-from-mail)
