@@ -4,24 +4,25 @@
 ;; Parts copyright (C) 2004 Angus Lees (gus AT inodes DOT org)
 
 ;; Author: Yvonne Thomson (yvonne AT thewatch DOT net)
-;; Version: 3.30
 ;; Keywords: planner, wanderlust, wl
-;; URL: http://sacha.free.net.ph/notebook/wiki/PlannerMode.php
+;; URL: http://www.plannerlove.com/
 
-;; This file is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
+;; This file is part of Planner.  It is not part of GNU Emacs.
+
+;; Planner is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
 ;; the Free Software Foundation; either version 2, or (at your option)
 ;; any later version.
 
-;; This file is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
+;; Planner is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with Planner; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -48,8 +49,9 @@
 ;;;_ + Contributors
 
 ;; Angus Lees (gus AT inodes DOT org) remade quite a bit of this file.
-;; Jeremy Cowgar (jeremy AT cowgar DOT com)
-;;   Updated to work with Wanderlust 2.12.0
+
+;; Jeremy Cowgar (jeremy AT cowgar DOT com) updated this to work with
+;; Wanderlust 2.12.0.
 
 ;;; Code:
 
@@ -89,7 +91,7 @@ Suitable for use in `planner-annotation-functions'."
 ;;;###autoload
 (defun planner-wl-browse-url (url)
   "If this is a Wanderlust URL, jump to it."
-  (when (string-match "^wl:/*\\(.+\\)/\\(.+\\)" url)
+  (when (string-match "\\`wl:/*\\(.+\\)/\\(.+\\)" url)
     (let ((group (match-string 1 url))
           (article (match-string 2 url)))
       (wl-summary-goto-folder-subr group 'no-sync t nil t)
@@ -98,7 +100,7 @@ Suitable for use in `planner-annotation-functions'."
       ;; force a non-nil return value
       t)))
 
-(planner-add-protocol "wl" 'planner-wl-browse-url nil)
+(planner-add-protocol "wl:/*" 'planner-wl-browse-url nil)
 (custom-add-option 'planner-annotation-functions
                    'planner-wl-annotation-from-wl)
 (add-hook 'planner-annotation-functions 'planner-wl-annotation-from-wl)
